@@ -5,8 +5,10 @@ function _aws_cdk_aws_mediatailor_CfnPlaybackConfigurationProps(p) {
     try {
         if (!visitedObjects.has(p.availSuppression))
             _aws_cdk_aws_mediatailor_CfnPlaybackConfiguration_AvailSuppressionProperty(p.availSuppression);
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
